from setuptools import setup, find_packages
import os

# Read the README file
def read_readme():
    readme_path = os.path.join(os.path.dirname(__file__), 'README.md')
    if os.path.exists(readme_path):
        with open(readme_path, 'r', encoding='utf-8') as f:
            return f.read()
    return "Ghost Brain - Advanced memory management and RAG capabilities for AI assistants"

# Read requirements
def read_requirements():
    requirements_path = os.path.join(os.path.dirname(__file__), 'requirements.txt')
    if os.path.exists(requirements_path):
        with open(requirements_path, 'r', encoding='utf-8') as f:
            reqs = [line.strip() for line in f if line.strip() and not line.startswith('#')]
            if 'python-multipart' not in reqs:
                reqs.append('python-multipart')
            return reqs
    return ['python-multipart']

setup(
    name="ghost-brain",
    version="0.1.3",
    author="Ghost Project Team",
    author_email="team@ghost.ai",
    description="Advanced memory management and RAG capabilities for AI assistants with CLI and environment variable configuration",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/AmberLee2427/ghost-brain",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.11",
    install_requires=read_requirements(),
    extras_require={
        "dev": [
            "pytest>=7.4.0",
            "pytest-asyncio>=0.21.0",
            "black>=23.0.0",
            "flake8>=6.0.0",
        ],
        "txtai": [
            "txtai[all]>=5.6.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "ghost-brain=ghost_brain.cli:main",
        ],
    },
    include_package_data=True,
    package_data={
        "ghost_brain": ["*.md", "*.txt"],
    },
    keywords="ai assistant memory rag embeddings llm cli environment-variables",
    project_urls={
        "Bug Reports": "https://github.com/AmberLee2427/ghost-brain/issues",
        "Source": "https://github.com/AmberLee2427/ghost-brain",
        "Documentation": "https://github.com/AmberLee2427/ghost-brain#readme",
    },
) 